package sun.security.pkcs;

import sun.security.util.DerOutputStream;
import java.io.IOException;
import sun.security.util.DerValue;
import sun.security.x509.AlgorithmId;

public class EncryptedPrivateKeyInfo
{
    private AlgorithmId algid;
    private byte[] encryptedData;
    private byte[] encoded;
    
    public EncryptedPrivateKeyInfo(byte[] encoding) throws IOException {
        if (encoding == null) {
            throw new IllegalArgumentException("encoding must not be null");
        }
        DerValue derValue = new DerValue(encoding);
        DerValue[] array = { derValue.data.getDerValue(), derValue.data.getDerValue() };
        if (derValue.data.available() != 0) {
            throw new IOException("overrun, bytes = " + derValue.data.available());
        }
        this.algid = AlgorithmId.parse(array[0]);
        if (array[0].data.available() != 0) {
            throw new IOException("encryptionAlgorithm field overrun");
        }
        this.encryptedData = array[1].getOctetString();
        if (array[1].data.available() != 0) {
            throw new IOException("encryptedData field overrun");
        }
        this.encoded = (byte[])encoding.clone();
        return;
    }
    
    public EncryptedPrivateKeyInfo(AlgorithmId algid, byte[] array) {
        this.algid = algid;
        this.encryptedData = (byte[])array.clone();
    }
    
    public AlgorithmId getAlgorithm() {
        return this.algid;
    }
    
    public byte[] getEncryptedData() {
        return (byte[])this.encryptedData.clone();
    }
    
    public byte[] getEncoded() throws IOException {
        if (this.encoded != null) {
            return (byte[])this.encoded.clone();
        }
        DerOutputStream derOutputStream = new DerOutputStream();
        DerOutputStream out = new DerOutputStream();
        this.algid.encode(out);
        out.putOctetString(this.encryptedData);
        derOutputStream.write((byte)48, out);
        this.encoded = derOutputStream.toByteArray();
        return (byte[])this.encoded.clone();
    }
    
    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof EncryptedPrivateKeyInfo)) {
            return false;
        }
        try {
            byte[] encoded = this.getEncoded();
            byte[] encoded2 = ((EncryptedPrivateKeyInfo)o).getEncoded();
            if (encoded.length != encoded2.length) {
                return false;
            }
            int i = 0;
            while (i < encoded.length) {
                if (encoded[i] != encoded2[i]) {
                    return false;
                }
                ++i;
            }
            return true;
        }
        catch (IOException ex) {
            return false;
        }
    }
    
    @Override
    public int hashCode() {
        int n = 0;
        for (int i = 0; i < this.encryptedData.length; ++i) {
            n += this.encryptedData[i] * i;
        }
        return n;
    }
}
